summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/editlistviewdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/editlistviewdialog.h')
-rw-r--r--kexi/formeditor/editlistviewdialog.h33
1 files changed, 17 insertions, 16 deletions
diff --git a/kexi/formeditor/editlistviewdialog.h b/kexi/formeditor/editlistviewdialog.h
index 09de4429..be2ae106 100644
--- a/kexi/formeditor/editlistviewdialog.h
+++ b/kexi/formeditor/editlistviewdialog.h
@@ -20,17 +20,17 @@
#ifndef EDITLISTVIEW_DIALOG_H
#define EDITLISTVIEW_DIALOG_H
-#include <qintdict.h>
-#include <qtoolbutton.h>
+#include <tqintdict.h>
+#include <tqtoolbutton.h>
#include <kdialogbase.h>
-class QFrame;
-class QListView;
-class QListViewItem;
+class TQFrame;
+class TQListView;
+class TQListViewItem;
class KListViewItem;
class KListView;
class KListBox;
-class QListBoxItem;
+class TQListBoxItem;
namespace KoProperty {
class Property;
@@ -40,25 +40,26 @@ namespace KoProperty {
namespace KFormDesigner {
//! A dialog to edit the contents of a listvuew (KListView or QListView)
/*! The dialog contains two pages, one to edit columns and one to edit ist items.
KoProperty::Editor is used in columns to edit column properties
- (there are two properties not supported by Qt Designer: 'width' and 'resizable').
+ (there are two properties not supported by TQt Designer: 'width' and 'resizable').
The user can enter list contents inside the list
using KListViewItem::setRenameable(). Pixmaps are not yet supported. */
class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- EditListViewDialog(QWidget *parent);
+ EditListViewDialog(TQWidget *tqparent);
~EditListViewDialog() {}
- int exec(QListView *listview);
+ int exec(TQListView *listview);
public slots:
// Columns page
- void updateItemProperties(QListBoxItem*);
+ void updateItemProperties(TQListBoxItem*);
void newItem();
void removeItem();
void MoveItemUp();
@@ -66,7 +67,7 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
void changeProperty(KoProperty::Set& set, KoProperty::Property& property);
// Contents page
- void updateButtons(QListViewItem*);
+ void updateButtons(TQListViewItem*);
void newRow();
void newChildRow();
void removeRow();
@@ -74,18 +75,18 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
void MoveRowDown();
protected:
/*! Loads all child items of \a item into \a listview (may be different from the \a items 's listview) as child of \a parent item.
This is used to copy the contents of a listview into another listview. */
- void loadChildNodes(QListView *listview, QListViewItem *item, QListViewItem *parent);
+ void loadChildNodes(TQListView *listview, TQListViewItem *item, TQListViewItem *tqparent);
protected:
enum { BNewRow = 10, BNewChild, BRemRow, BRowUp, BRowDown , BColAdd = 20, BColRem, BColUp, BColDown };
KoProperty::Editor *m_editor;
KoProperty::Set *m_propSet;
- QFrame *m_contents, *m_column;
+ TQFrame *m_contents, *m_column;
KListBox *m_listbox;
KListView *m_listview;
- QIntDict<QToolButton> m_buttons;
+ TQIntDict<TQToolButton> m_buttons;
};
}
@@ -40,25 +40,26 @@ namespace KoProperty {
namespace KFormDesigner {
-//! A dialog to edit the contents of a listvuew (KListView or QListView)
+//! A dialog to edit the contents of a listvuew (KListView or TQListView)
/*! The dialog contains two pages, one to edit columns and one to edit ist items.
KoProperty::Editor is used in columns to edit column properties
@@ -74,18 +75,18 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
void MoveRowDown();
protected:
- /*! Loads all child items of \a item into \a listview (may be different from the \a items 's listview) as child of \a parent item.
+ /*! Loads all child items of \a item into \a listview (may be different from the \a items 's listview) as child of \a tqparent item.
This is used to copy the contents of a listview into another listview. */